searchData={"items":[{"type":"module","title":"Complex","doc":"*Complex* is a library that brings complex number support to Elixir.\n\nEach complex number is represented as a `%Complex{}` struct, that holds\nthe real and imaginary parts. There are functions for the creation and\nmanipulation of complex numbers.\n\nThis module implements mathematical functions such as `add/2`, `subtract/2`,\n`divide/2`, and `multiply/2` that subtitute the `+`, `-`, `/` and `*` operators.\n\nOperator overloading is provided through `Complex.Kernel`","ref":"Complex.html"},{"type":"module","title":"Examples - Complex","doc":"iex> Complex.new(3, 4)\n    %Complex{im: 4.0, re: 3.0}\n\n    iex> Complex.new(0, 1)\n    %Complex{im: 1.0, re: 0.0}","ref":"Complex.html#module-examples"},{"type":"function","title":"Complex.abs/1","doc":"Returns the magnitude (length) of the provided complex number.","ref":"Complex.html#abs/1"},{"type":"function","title":"See also - Complex.abs/1","doc":"`new/2`, `phase/1`","ref":"Complex.html#abs/1-see-also"},{"type":"function","title":"Examples - Complex.abs/1","doc":"iex> Complex.abs(Complex.from_polar(1, :math.pi/2))\n    1.0","ref":"Complex.html#abs/1-examples"},{"type":"function","title":"Complex.abs_squared/1","doc":"Returns the square of the magnitude of the provided complex number.\n\nThe square of the magnitude is faster to compute---no square roots!","ref":"Complex.html#abs_squared/1"},{"type":"function","title":"See also - Complex.abs_squared/1","doc":"`new/2`, `abs/1`","ref":"Complex.html#abs_squared/1-see-also"},{"type":"function","title":"Examples - Complex.abs_squared/1","doc":"iex> Complex.abs_squared(Complex.from_polar(1, :math.pi/2))\n    1.0\n\n    iex> Complex.abs_squared(Complex.from_polar(2, :math.pi/2))\n    4.0","ref":"Complex.html#abs_squared/1-examples"},{"type":"function","title":"Complex.acos/1","doc":"Returns a new complex that is the inverse cosine (i.e., arccosine) of the\nprovided parameter.","ref":"Complex.html#acos/1"},{"type":"function","title":"See also - Complex.acos/1","doc":"`cos/1`","ref":"Complex.html#acos/1-see-also"},{"type":"function","title":"Examples - Complex.acos/1","doc":"iex> Complex.acos(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.3169578969248164, re: -3.141592653589793}","ref":"Complex.html#acos/1-examples"},{"type":"function","title":"Complex.acosh/1","doc":"Returns a new complex that is the inverse hyperbolic cosine (i.e., arccosh)\nof the provided parameter.","ref":"Complex.html#acosh/1"},{"type":"function","title":"See also - Complex.acosh/1","doc":"`cosh/1`","ref":"Complex.html#acosh/1-see-also"},{"type":"function","title":"Examples - Complex.acosh/1","doc":"iex> Complex.acosh(Complex.from_polar(2,:math.pi))\n    %Complex{im: -3.141592653589793, re: -1.3169578969248164}","ref":"Complex.html#acosh/1-examples"},{"type":"function","title":"Complex.acot/1","doc":"Returns a new complex that is the inverse cotangent (i.e., arccotangent) of\nthe provided parameter.","ref":"Complex.html#acot/1"},{"type":"function","title":"See also - Complex.acot/1","doc":"`cot/1`","ref":"Complex.html#acot/1-see-also"},{"type":"function","title":"Examples - Complex.acot/1","doc":"iex> Complex.acot(Complex.from_polar(2,:math.pi))\n    %Complex{im: -9.71445146547012e-17, re: -0.46364760900080615}\n\n    iex> Complex.cot(Complex.acot(Complex.new(2,3)))\n    %Complex{im: 2.9999999999999996, re: 1.9999999999999993}","ref":"Complex.html#acot/1-examples"},{"type":"function","title":"Complex.acoth/1","doc":"Returns a new complex that is the inverse hyperbolic cotangent (i.e., arccoth)\nof the provided parameter.","ref":"Complex.html#acoth/1"},{"type":"function","title":"See also - Complex.acoth/1","doc":"`coth/1`","ref":"Complex.html#acoth/1-see-also"},{"type":"function","title":"Examples - Complex.acoth/1","doc":"iex> Complex.acoth(Complex.from_polar(2,:math.pi))\n    %Complex{im: -8.164311994315688e-17, re: -0.5493061443340548}\n\n    iex> Complex.coth(Complex.acoth(Complex.new(2,3)))\n    %Complex{im: 2.999999999999998, re: 2.000000000000001}","ref":"Complex.html#acoth/1-examples"},{"type":"function","title":"Complex.acsc/1","doc":"Returns a new complex that is the inverse cosecant (i.e., arccosecant) of\nthe provided parameter.","ref":"Complex.html#acsc/1"},{"type":"function","title":"See also - Complex.acsc/1","doc":"`sec/1`","ref":"Complex.html#acsc/1-see-also"},{"type":"function","title":"Examples - Complex.acsc/1","doc":"iex> Complex.acsc(Complex.from_polar(2,:math.pi))\n    %Complex{im: 0.0, re: -0.5235987755982988}\n\n    iex> Complex.csc(Complex.acsc(Complex.new(2,3)))\n    %Complex{im: 3.0, re: 1.9999999999999993}","ref":"Complex.html#acsc/1-examples"},{"type":"function","title":"Complex.acsch/1","doc":"Returns a new complex that is the inverse hyperbolic cosecant (i.e., arccsch)\nof the provided parameter.","ref":"Complex.html#acsch/1"},{"type":"function","title":"See also - Complex.acsch/1","doc":"`csch/1`","ref":"Complex.html#acsch/1-see-also"},{"type":"function","title":"Examples - Complex.acsch/1","doc":"iex> Complex.acsch(Complex.from_polar(2,:math.pi))\n    %Complex{im: -5.4767869826420256e-17, re: -0.48121182505960336}\n\n    iex> Complex.csch(Complex.acsch(Complex.new(2,3)))\n    %Complex{im: 3.0000000000000018, re: 1.9999999999999984}","ref":"Complex.html#acsch/1-examples"},{"type":"function","title":"Complex.add/2","doc":"Returns a new complex that is the sum of the provided complex numbers.  Also\nsupports a mix of complex and number.","ref":"Complex.html#add/2"},{"type":"function","title":"See also - Complex.add/2","doc":"`div/2`, `multiply/2`, `subtract/2`","ref":"Complex.html#add/2-see-also"},{"type":"function","title":"Examples - Complex.add/2","doc":"iex> Complex.add(Complex.from_polar(1, :math.pi/2), Complex.from_polar(1, :math.pi/2))\n    %Complex{im: 2.0, re: 1.2246467991473532e-16}\n\n    iex> Complex.add(Complex.new(4, 4), 1)\n    %Complex{im: 4.0, re: 5.0}\n\n    iex> Complex.add(2, Complex.new(4, 3))\n    %Complex{im: 3.0, re: 6.0}\n\n    iex> Complex.add(2, 3)\n    5\n\n    iex> Complex.add(2.0, 2)\n    4.0","ref":"Complex.html#add/2-examples"},{"type":"function","title":"Complex.asec/1","doc":"Returns a new complex that is the inverse secant (i.e., arcsecant) of\nthe provided parameter.","ref":"Complex.html#asec/1"},{"type":"function","title":"See also - Complex.asec/1","doc":"`sec/1`","ref":"Complex.html#asec/1-see-also"},{"type":"function","title":"Examples - Complex.asec/1","doc":"iex> Complex.asec(Complex.from_polar(2,:math.pi))\n    %Complex{im: -0.0, re: 2.0943951023931957}\n\n    iex> Complex.sec(Complex.asec(Complex.new(2,3)))\n    %Complex{im: 2.9999999999999982, re: 1.9999999999999987}","ref":"Complex.html#asec/1-examples"},{"type":"function","title":"Complex.asech/1","doc":"Returns a new complex that is the inverse hyperbolic secant (i.e., arcsech)\nof the provided parameter.","ref":"Complex.html#asech/1"},{"type":"function","title":"See also - Complex.asech/1","doc":"`sech/1`","ref":"Complex.html#asech/1-see-also"},{"type":"function","title":"Examples - Complex.asech/1","doc":"iex> Complex.asech(Complex.from_polar(2,:math.pi))\n    %Complex{im: -2.0943951023931953, re: 0.0}\n\n    iex> Complex.sech(Complex.asech(Complex.new(2,3)))\n    %Complex{im: 2.999999999999999, re: 2.0}","ref":"Complex.html#asech/1-examples"},{"type":"function","title":"Complex.asin/1","doc":"Returns a new complex that is the inverse sine (i.e., arcsine) of the\nprovided parameter.","ref":"Complex.html#asin/1"},{"type":"function","title":"See also - Complex.asin/1","doc":"`sin/1`","ref":"Complex.html#asin/1-see-also"},{"type":"function","title":"Examples - Complex.asin/1","doc":"iex> Complex.asin(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.3169578969248164, re: -1.5707963267948966}","ref":"Complex.html#asin/1-examples"},{"type":"function","title":"Complex.asinh/1","doc":"Returns a new complex that is the inverse hyperbolic sine (i.e., arcsinh) of\nthe provided parameter.","ref":"Complex.html#asinh/1"},{"type":"function","title":"See also - Complex.asinh/1","doc":"`sinh/1`","ref":"Complex.html#asinh/1-see-also"},{"type":"function","title":"Examples - Complex.asinh/1","doc":"iex> Complex.asinh(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.0953573965284052e-16, re: -1.4436354751788099}\n\n    iex> Complex.sinh(Complex.asinh(Complex.new(2,3)))\n    %Complex{im: 3.0, re: 2.0000000000000004}","ref":"Complex.html#asinh/1-examples"},{"type":"function","title":"Complex.atan2/2","doc":"$atan2(b, a)$ returns the phase of the complex number $a + bi$.","ref":"Complex.html#atan2/2"},{"type":"function","title":"See also - Complex.atan2/2","doc":"`tan/1`, `atan/1`","ref":"Complex.html#atan2/2-see-also"},{"type":"function","title":"Examples - Complex.atan2/2","doc":"iex> phase = Complex.atan2(2, 2)\n    iex> phase == :math.pi() / 4\n    true\n\n    iex> phase = Complex.atan2(2, Complex.new(0))\n    iex> phase == Complex.new(:math.pi() / 2, 0)\n    true","ref":"Complex.html#atan2/2-examples"},{"type":"function","title":"Complex.atan/1","doc":"Returns a new complex that is the inverse tangent (i.e., arctangent) of the\nprovided parameter.","ref":"Complex.html#atan/1"},{"type":"function","title":"See also - Complex.atan/1","doc":"`tan/1`, `atan2/2`","ref":"Complex.html#atan/1-see-also"},{"type":"function","title":"Examples - Complex.atan/1","doc":"iex> Complex.atan(Complex.from_polar(2,:math.pi))\n    %Complex{im: 0.0, re: -1.1071487177940904}\n\n    iex> Complex.tan(Complex.atan(Complex.new(2,3)))\n    %Complex{im: 2.9999999999999996, re: 2.0}","ref":"Complex.html#atan/1-examples"},{"type":"function","title":"Complex.atanh/1","doc":"Returns a new complex that is the inverse hyperbolic tangent (i.e., arctanh)\nof the provided parameter.","ref":"Complex.html#atanh/1"},{"type":"function","title":"See also - Complex.atanh/1","doc":"`tanh/1`","ref":"Complex.html#atanh/1-see-also"},{"type":"function","title":"Examples - Complex.atanh/1","doc":"iex> Complex.atanh(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.5707963267948966, re: -0.5493061443340549}\n\n    iex> Complex.tanh(Complex.atanh(Complex.new(2,3)))\n    %Complex{im: 3.0, re: 1.9999999999999993}","ref":"Complex.html#atanh/1-examples"},{"type":"function","title":"Complex.cbrt/1","doc":"Returns a new number that is the complex cube root of the provided\nnumber.\n\nReturns the principal branch of the cube root for complex inputs.","ref":"Complex.html#cbrt/1"},{"type":"function","title":"See also - Complex.cbrt/1","doc":"`abs/1`, `phase/1`, `sqrt/1`","ref":"Complex.html#cbrt/1-see-also"},{"type":"function","title":"Examples - Complex.cbrt/1","doc":"iex> Complex.cbrt(-8)\n    -2.0\n\nWhen a negative number is given as a complex input,\nthe output now changes. Instead of still giving a\nnegative number, we now get a number with phase\n$\\frac{\\pi}{3}$\n\n    iex> z = Complex.cbrt(Complex.new(-8, 0))\n    %Complex{re: 1.0000000000000002, im: 1.7320508075688772}\n    iex> Complex.abs(z)\n    2.0\n    iex> Complex.phase(z)\n    1.0471975511965976\n    iex> :math.pi() / 3\n    1.0471975511965976","ref":"Complex.html#cbrt/1-examples"},{"type":"function","title":"Complex.conjugate/1","doc":"Returns a new complex that is the complex conjugate of the provided complex\nnumber.\n\nIf $z = a + bi$, $conjugate(z) = z^* = a - bi$","ref":"Complex.html#conjugate/1"},{"type":"function","title":"See also - Complex.conjugate/1","doc":"`abs/2`, `phase/1`","ref":"Complex.html#conjugate/1-see-also"},{"type":"function","title":"Examples - Complex.conjugate/1","doc":"iex> Complex.conjugate(Complex.new(1,2))\n    %Complex{im: -2.0, re: 1.0}","ref":"Complex.html#conjugate/1-examples"},{"type":"function","title":"Complex.cos/1","doc":"Returns a new complex that is the cosine of the provided parameter.","ref":"Complex.html#cos/1"},{"type":"function","title":"See also - Complex.cos/1","doc":"`sin/1`, `tan/1`","ref":"Complex.html#cos/1-see-also"},{"type":"function","title":"Examples - Complex.cos/1","doc":"iex> Complex.cos(Complex.from_polar(2,:math.pi))\n    %Complex{im: 2.2271363664699914e-16, re: -0.4161468365471424}","ref":"Complex.html#cos/1-examples"},{"type":"function","title":"Complex.cosh/1","doc":"Returns a new complex that is the hyperbolic cosine of the provided\nparameter.","ref":"Complex.html#cosh/1"},{"type":"function","title":"See also - Complex.cosh/1","doc":"`sinh/1`, `tanh/1`","ref":"Complex.html#cosh/1-see-also"},{"type":"function","title":"Examples - Complex.cosh/1","doc":"iex> Complex.cosh(Complex.from_polar(2,:math.pi))\n    %Complex{im: -8.883245978848233e-16, re: 3.7621956910836314}","ref":"Complex.html#cosh/1-examples"},{"type":"function","title":"Complex.cot/1","doc":"Returns a new complex that is the cotangent of the provided parameter.","ref":"Complex.html#cot/1"},{"type":"function","title":"See also - Complex.cot/1","doc":"`sin/1`, `cos/1`, `tan/1`","ref":"Complex.html#cot/1-see-also"},{"type":"function","title":"Examples - Complex.cot/1","doc":"iex> Complex.cot(Complex.from_polar(2,:math.pi))\n    %Complex{im: -2.962299212953233e-16, re: 0.45765755436028577}","ref":"Complex.html#cot/1-examples"},{"type":"function","title":"Complex.coth/1","doc":"Returns a new complex that is the hyperbolic cotangent of the provided\nparameter.","ref":"Complex.html#coth/1"},{"type":"function","title":"See also - Complex.coth/1","doc":"`sinh/1`, `cosh/1`, `tanh/1`","ref":"Complex.html#coth/1-see-also"},{"type":"function","title":"Examples - Complex.coth/1","doc":"iex> Complex.coth(Complex.from_polar(2,:math.pi))\n    %Complex{im: -1.8619978115303644e-17, re: -1.037314720727548}","ref":"Complex.html#coth/1-examples"},{"type":"function","title":"Complex.csc/1","doc":"Returns a new complex that is the cosecant of the provided parameter.","ref":"Complex.html#csc/1"},{"type":"function","title":"See also - Complex.csc/1","doc":"`sec/1`, `sin/1`, `cos/1`, `tan/1`","ref":"Complex.html#csc/1-see-also"},{"type":"function","title":"Examples - Complex.csc/1","doc":"iex> Complex.csc(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.2327514463765779e-16, re: -1.0997501702946164}","ref":"Complex.html#csc/1-examples"},{"type":"function","title":"Complex.csch/1","doc":"Returns a new complex that is the hyperbolic cosecant of the provided\nparameter.","ref":"Complex.html#csch/1"},{"type":"function","title":"See also - Complex.csch/1","doc":"`sinh/1`, `cosh/1`, `tanh/1`","ref":"Complex.html#csch/1-see-also"},{"type":"function","title":"Examples - Complex.csch/1","doc":"iex> Complex.csch(Complex.from_polar(2,:math.pi))\n    %Complex{im: -7.00520014334671e-17, re: -0.2757205647717832}","ref":"Complex.html#csch/1-examples"},{"type":"function","title":"Complex.divide/2","doc":"Returns a new complex that is the ratio (division) of the provided complex\nnumbers.","ref":"Complex.html#divide/2"},{"type":"function","title":"See also - Complex.divide/2","doc":"`add/2`, `multiply/2`, `subtract/2`","ref":"Complex.html#divide/2-see-also"},{"type":"function","title":"Examples - Complex.divide/2","doc":"iex> Complex.divide(Complex.from_polar(1, :math.pi/2), Complex.from_polar(1, :math.pi/2))\n    %Complex{im: 0.0, re: 1.0}","ref":"Complex.html#divide/2-examples"},{"type":"function","title":"Complex.erf/1","doc":"Calculates $erf(z)$ of the argument, as defined by:\n\n$$erf(z) = \\frac{2}{\\sqrt{\\pi}} \\int_{0}^{z} e^{-t^2}$$","ref":"Complex.html#erf/1"},{"type":"function","title":"Examples - Complex.erf/1","doc":"iex> x = Complex.erf(0.5)\n    iex> Float.round(x, 5)\n    0.52050\n\n    iex> z = Complex.erf(Complex.new(-0.5))\n    iex> z.im\n    0.0\n    iex> Float.round(z.re, 5)\n    -0.52050\n\n    iex> Complex.erf(Complex.new(1, 1))\n    ** (ArithmeticError) erf not implemented for non-real numbers","ref":"Complex.html#erf/1-examples"},{"type":"function","title":"Complex.erf_inv/1","doc":"Calculates $erf^-1(z)$ of the argument, as defined by:\n\n$$erf(erf^-1(z)) = z$$","ref":"Complex.html#erf_inv/1"},{"type":"function","title":"Examples - Complex.erf_inv/1","doc":"iex> Complex.erf_inv(0.5204998778130465)\n    0.5000000069276399\n\n    iex> Complex.erf_inv(Complex.new(-0.5204998778130465))\n    %Complex{im: 0.0, re: -0.5000000069276399}\n\n    iex> Complex.erf_inv(Complex.new(1, 1))\n    ** (ArithmeticError) erf_inv not implemented for non-real numbers","ref":"Complex.html#erf_inv/1-examples"},{"type":"function","title":"Complex.erfc/1","doc":"Calculates $erfc(z)$ of the argument, as defined by:\n\n$$erfc(z) = 1 - erf(z)$$","ref":"Complex.html#erfc/1"},{"type":"function","title":"Examples - Complex.erfc/1","doc":"iex> x = Complex.erfc(0.5)\n    iex> Float.round(x, 5)\n    0.47950\n\n    iex> z = Complex.erfc(Complex.new(-0.5))\n    iex> z.im\n    0.0\n    iex> Float.round(z.re, 5)\n    1.52050\n\n    iex> Complex.erfc(Complex.new(1, 1))\n    ** (ArithmeticError) erfc not implemented for non-real numbers","ref":"Complex.html#erfc/1-examples"},{"type":"function","title":"Complex.exp/1","doc":"Returns a new complex that is the complex exponential of the provided\ncomplex number: $exp(z) = e^z$.","ref":"Complex.html#exp/1"},{"type":"function","title":"See also - Complex.exp/1","doc":"`log/1`","ref":"Complex.html#exp/1-see-also"},{"type":"function","title":"Examples - Complex.exp/1","doc":"iex> Complex.exp(Complex.from_polar(2,:math.pi))\n    %Complex{im: 3.3147584285483636e-17, re: 0.1353352832366127}","ref":"Complex.html#exp/1-examples"},{"type":"function","title":"Complex.from_polar/1","doc":"Turns a representation in polar coordinates $r\\phase\\phi$, into\nthe complex number $z = r.cos(\\phi) + r.sin(\\phi) i$","ref":"Complex.html#from_polar/1"},{"type":"function","title":"See also - Complex.from_polar/1","doc":"`new/2`","ref":"Complex.html#from_polar/1-see-also"},{"type":"function","title":"Examples - Complex.from_polar/1","doc":"iex> Complex.from_polar(1, :math.pi/2)\n    %Complex{im: 1.0, re: 6.123233995736766e-17}\n\n    iex> polar = Complex.to_polar(%Complex{re: 6, im: 20})\n    iex> Complex.from_polar(polar)\n    %Complex{im: 20.0, re: 6.0}","ref":"Complex.html#from_polar/1-examples"},{"type":"function","title":"Complex.from_polar/2","doc":"","ref":"Complex.html#from_polar/2"},{"type":"function","title":"Complex.imag/1","doc":"Returns the imaginary part of the provided complex number.\nIf a real number is provided, 0 is returned.","ref":"Complex.html#imag/1"},{"type":"function","title":"See also - Complex.imag/1","doc":"`real/1`","ref":"Complex.html#imag/1-see-also"},{"type":"function","title":"Examples - Complex.imag/1","doc":"iex> Complex.imag(Complex.new(1, 2))\n    2.0\n\n    iex> Complex.imag(1)\n    0","ref":"Complex.html#imag/1-examples"},{"type":"function","title":"Complex.ln/1","doc":"","ref":"Complex.html#ln/1"},{"type":"function","title":"Complex.log2/1","doc":"Returns a new complex that is the complex log base 2 of the provided\ncomplex number.","ref":"Complex.html#log2/1"},{"type":"function","title":"See also - Complex.log2/1","doc":"`log/1`, `log10/1`","ref":"Complex.html#log2/1-see-also"},{"type":"function","title":"Examples - Complex.log2/1","doc":"iex> Complex.log2(Complex.from_polar(2,:math.pi))\n    %Complex{im: 4.532360141827194, re: 1.0}","ref":"Complex.html#log2/1-examples"},{"type":"function","title":"Complex.log10/1","doc":"Returns a new complex that is the complex log base 10 of the provided\ncomplex number.","ref":"Complex.html#log10/1"},{"type":"function","title":"See also - Complex.log10/1","doc":"`log/1`","ref":"Complex.html#log10/1-see-also"},{"type":"function","title":"Examples - Complex.log10/1","doc":"iex> Complex.log10(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.3643763538418412, re: 0.30102999566398114}","ref":"Complex.html#log10/1-examples"},{"type":"function","title":"Complex.log/1","doc":"Returns a new complex that is the complex natural log of the provided\ncomplex number, $log(z) = log_e(z)$.","ref":"Complex.html#log/1"},{"type":"function","title":"See also - Complex.log/1","doc":"`exp/1`","ref":"Complex.html#log/1-see-also"},{"type":"function","title":"Examples - Complex.log/1","doc":"iex> Complex.log(Complex.from_polar(2,:math.pi))\n    %Complex{im: 3.141592653589793, re: 0.6931471805599453}","ref":"Complex.html#log/1-examples"},{"type":"function","title":"Complex.multiply/2","doc":"Returns a new complex that is the product of the provided complex numbers.\nAlso supports a mix of complex and number.","ref":"Complex.html#multiply/2"},{"type":"function","title":"See also - Complex.multiply/2","doc":"`add/2`, `div/2`, `subtract/2`","ref":"Complex.html#multiply/2-see-also"},{"type":"function","title":"Examples - Complex.multiply/2","doc":"iex> Complex.multiply(Complex.new(1,2), Complex.new(3,4))\n    %Complex{im: 10.0, re: -5.0}\n\n    iex> Complex.multiply(Complex.new(0, 1), Complex.new(0, 1))\n    %Complex{im: 0.0, re: -1.0}\n\n    iex> Complex.multiply(Complex.new(1, 2), 3)\n    %Complex{im: 6.0, re: 3.0}\n\n    iex> Complex.multiply(3, Complex.new(1, 2))\n    %Complex{im: 6.0, re: 3.0}\n\n    iex> Complex.multiply(-2, Complex.new(:infinity, :neg_infinity))\n    %Complex{im: :nan, re: :nan}","ref":"Complex.html#multiply/2-examples"},{"type":"function","title":"Complex.negate/1","doc":"Returns a new complex that is the \"negation\" of the provided parameter.\nThat is, the real and imaginary parts are negated.","ref":"Complex.html#negate/1"},{"type":"function","title":"See also - Complex.negate/1","doc":"`new/2`","ref":"Complex.html#negate/1-see-also"},{"type":"function","title":"Examples - Complex.negate/1","doc":"iex> Complex.negate(Complex.new(3,5))\n    %Complex{im: -5.0, re: -3.0}","ref":"Complex.html#negate/1-examples"},{"type":"function","title":"Complex.new/2","doc":"Returns a new complex with specified real and imaginary components. The\nimaginary part defaults to zero so a real number can be created with `new/1`.","ref":"Complex.html#new/2"},{"type":"function","title":"See also - Complex.new/2","doc":"`from_polar/2`","ref":"Complex.html#new/2-see-also"},{"type":"function","title":"Examples - Complex.new/2","doc":"iex> Complex.new(3, 4)\n    %Complex{im: 4.0, re: 3.0}\n\n    iex> Complex.new(2)\n    %Complex{im: 0.0, re: 2.0}\n\n    iex> Complex.new(:infinity)\n    %Complex{im: 0.0, re: :infinity}\n\n    iex> Complex.new(:nan, :neg_infinity)\n    %Complex{im: :neg_infinity, re: :nan}","ref":"Complex.html#new/2-examples"},{"type":"type","title":"Complex.non_finite_number/0","doc":"","ref":"Complex.html#t:non_finite_number/0"},{"type":"function","title":"Complex.parse/1","doc":"Parses a complex number from a string.  The values of the real and imaginary\nparts must be represented by a float, including decimal and at least one\ntrailing digit (e.g. 1.2, 0.4).","ref":"Complex.html#parse/1"},{"type":"function","title":"See also - Complex.parse/1","doc":"`new/2`","ref":"Complex.html#parse/1-see-also"},{"type":"function","title":"Examples - Complex.parse/1","doc":"iex> Complex.parse(\"1.1+2.2i\")\n    {%Complex{im: 2.2, re: 1.1}, \"\"}\n\n    iex> Complex.parse(\"1+2i\")\n    {%Complex{im: 2.0, re: 1.0}, \"\"}\n\n    iex> Complex.parse(\"2-3i\")\n    {%Complex{im: -3.0, re: 2.0}, \"\"}\n\n    iex> Complex.parse(\"-1.0-3.i\")\n    {%Complex{im: -3.0, re: -1.0}, \"\"}\n\n    iex> Complex.parse(\"-1.0+3.i 2.2+3.3i\")\n    {%Complex{im: 3.0, re: -1.0}, \" 2.2+3.3i\"}\n\n    iex> Complex.parse(\"1e-4-3e-3i\")\n    {%Complex{im: -3.0e-3, re: 1.0e-4}, \"\"}\n\n    iex> Complex.parse(\"2i\")\n    {%Complex{im: 2.0, re: 0.0}, \"\"}\n\n    iex> Complex.parse(\"-3.0i\")\n    {%Complex{im: -3.0, re: 0.0}, \"\"}\n\n    iex> Complex.parse(\"NaN+Infi\")\n    {%Complex{im: :infinity, re: :nan}, \"\"}\n\n    iex> Complex.parse(\"-Inf+NaNi\")\n    {%Complex{im: :nan, re: :neg_infinity}, \"\"}\n\n    iex> Complex.parse(\"Inf-NaNi\")\n    {%Complex{im: :nan, re: :infinity}, \"\"}\n\n    iex> Complex.parse(\"Inf\")\n    {%Complex{im: 0.0, re: :infinity}, \"\"}","ref":"Complex.html#parse/1-examples"},{"type":"function","title":"Complex.phase/1","doc":"Returns the phase angle of the supplied complex, in radians.","ref":"Complex.html#phase/1"},{"type":"function","title":"See also - Complex.phase/1","doc":"`new/2`, `from_polar/2`","ref":"Complex.html#phase/1-see-also"},{"type":"function","title":"Examples - Complex.phase/1","doc":"iex> Complex.phase(Complex.from_polar(1,:math.pi/2))\n    1.5707963267948966","ref":"Complex.html#phase/1-examples"},{"type":"function","title":"Complex.pow/2","doc":"Returns a new complex that is the provided parameter a raised to the\ncomplex power b.","ref":"Complex.html#pow/2"},{"type":"function","title":"See also - Complex.pow/2","doc":"`log/1`, `log10/1`","ref":"Complex.html#pow/2-see-also"},{"type":"function","title":"Examples - Complex.pow/2","doc":"iex> Complex.pow(Complex.from_polar(2,:math.pi), Complex.new(0, 1))\n    %Complex{im: 0.027612020368333014, re: 0.03324182700885666}","ref":"Complex.html#pow/2-examples"},{"type":"function","title":"Complex.power/2","doc":"","ref":"Complex.html#power/2"},{"type":"function","title":"Complex.real/1","doc":"Returns the real part of the provided complex number.","ref":"Complex.html#real/1"},{"type":"function","title":"See also - Complex.real/1","doc":"`imag/1`","ref":"Complex.html#real/1-see-also"},{"type":"function","title":"Examples - Complex.real/1","doc":"iex> Complex.real(Complex.new(1, 2))\n    1.0\n\n    iex> Complex.real(1)\n    1","ref":"Complex.html#real/1-examples"},{"type":"function","title":"Complex.sec/1","doc":"Returns a new complex that is the secant of the provided parameter.","ref":"Complex.html#sec/1"},{"type":"function","title":"See also - Complex.sec/1","doc":"`sin/1`, `cos/1`, `tan/1`","ref":"Complex.html#sec/1-see-also"},{"type":"function","title":"Examples - Complex.sec/1","doc":"iex> Complex.sec(Complex.from_polar(2,:math.pi))\n    %Complex{im: -1.2860374461837126e-15, re: -2.402997961722381}","ref":"Complex.html#sec/1-examples"},{"type":"function","title":"Complex.sech/1","doc":"Returns a new complex that is the hyperbolic secant of the provided\nparameter.","ref":"Complex.html#sech/1"},{"type":"function","title":"See also - Complex.sech/1","doc":"`sinh/1`, `cosh/1`, `tanh/1`","ref":"Complex.html#sech/1-see-also"},{"type":"function","title":"Examples - Complex.sech/1","doc":"iex> Complex.sech(Complex.from_polar(2,:math.pi))\n    %Complex{im: 6.27608655779184e-17, re: 0.26580222883407967}","ref":"Complex.html#sech/1-examples"},{"type":"function","title":"Complex.sin/1","doc":"Returns a new complex that is the sine of the provided parameter.","ref":"Complex.html#sin/1"},{"type":"function","title":"See also - Complex.sin/1","doc":"`cos/1`, `tan/1`","ref":"Complex.html#sin/1-see-also"},{"type":"function","title":"Examples - Complex.sin/1","doc":"iex> Complex.sin(Complex.from_polar(2,:math.pi))\n    %Complex{im: -1.0192657827055095e-16, re: -0.9092974268256817}","ref":"Complex.html#sin/1-examples"},{"type":"function","title":"Complex.sinh/1","doc":"Returns a new complex that is the hyperbolic sine of the provided parameter.","ref":"Complex.html#sinh/1"},{"type":"function","title":"See also - Complex.sinh/1","doc":"`cosh/1`, `tanh/1`","ref":"Complex.html#sinh/1-see-also"},{"type":"function","title":"Examples - Complex.sinh/1","doc":"iex> Complex.sinh(Complex.from_polar(2,:math.pi))\n    %Complex{im: 9.214721821703068e-16, re: -3.626860407847019}","ref":"Complex.html#sinh/1-examples"},{"type":"function","title":"Complex.sqrt/1","doc":"Returns a new complex that is the complex square root of the provided\ncomplex number.","ref":"Complex.html#sqrt/1"},{"type":"function","title":"See also - Complex.sqrt/1","doc":"`abs/1`, `cbrt/1`, `phase/1`","ref":"Complex.html#sqrt/1-see-also"},{"type":"function","title":"Examples - Complex.sqrt/1","doc":"iex> Complex.sqrt(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.4142135623730951, re: 8.659560562354933e-17}","ref":"Complex.html#sqrt/1-examples"},{"type":"function","title":"Complex.square/1","doc":"Returns a new complex that is the square of the provided complex number.","ref":"Complex.html#square/1"},{"type":"function","title":"See also - Complex.square/1","doc":"`multiply/2`","ref":"Complex.html#square/1-see-also"},{"type":"function","title":"Examples - Complex.square/1","doc":"iex> Complex.square(Complex.new(2.0, 0.0))\n    %Complex{im: 0.0, re: 4.0}\n\n    iex> Complex.square(Complex.new(0, 1))\n    %Complex{im: 0.0, re: -1.0}","ref":"Complex.html#square/1-examples"},{"type":"function","title":"Complex.subtract/2","doc":"Returns a new complex that is the difference of the provided complex numbers.\nAlso supports a mix of complex and number.","ref":"Complex.html#subtract/2"},{"type":"function","title":"See also - Complex.subtract/2","doc":"`add/2`, `div/2`, `multiply/2`","ref":"Complex.html#subtract/2-see-also"},{"type":"function","title":"Examples - Complex.subtract/2","doc":"iex> Complex.subtract(Complex.new(1,2), Complex.new(3,4))\n    %Complex{im: -2.0, re: -2.0}\n\n    iex> Complex.subtract(Complex.new(1, 2), 3)\n    %Complex{im: 2.0, re: -2.0}\n\n    iex> Complex.subtract(10, Complex.new(1, 2))\n    %Complex{im: -2.0, re: 9.0}","ref":"Complex.html#subtract/2-examples"},{"type":"type","title":"Complex.t/0","doc":"A complex number represented as a `%Complex{}` struct.","ref":"Complex.html#t:t/0"},{"type":"function","title":"Complex.tan/1","doc":"Returns a new complex that is the tangent of the provided parameter.","ref":"Complex.html#tan/1"},{"type":"function","title":"See also - Complex.tan/1","doc":"`sin/1`, `cos/1`","ref":"Complex.html#tan/1-see-also"},{"type":"function","title":"Examples - Complex.tan/1","doc":"iex> Complex.tan(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.4143199004457915e-15, re: 2.185039863261519}","ref":"Complex.html#tan/1-examples"},{"type":"function","title":"Complex.tanh/1","doc":"Returns a new complex that is the hyperbolic tangent of the provided\nparameter.","ref":"Complex.html#tanh/1"},{"type":"function","title":"See also - Complex.tanh/1","doc":"`sinh/1`, `cosh/1`","ref":"Complex.html#tanh/1-see-also"},{"type":"function","title":"Examples - Complex.tanh/1","doc":"iex> Complex.tanh(Complex.from_polar(2,:math.pi))\n    %Complex{im: 1.7304461302709575e-17, re: -0.9640275800758169}","ref":"Complex.html#tanh/1-examples"},{"type":"function","title":"Complex.to_polar/1","doc":"Returns the polar coordinates of the supplied complex.  That is, the\nreturned tuple {r,phi} is the magnitude and phase (in radians) of z.","ref":"Complex.html#to_polar/1"},{"type":"function","title":"See also - Complex.to_polar/1","doc":"`from_polar/2`","ref":"Complex.html#to_polar/1-see-also"},{"type":"function","title":"Examples - Complex.to_polar/1","doc":"iex> Complex.to_polar(Complex.from_polar(1,:math.pi/2))\n    {1.0, 1.5707963267948966}","ref":"Complex.html#to_polar/1-examples"},{"type":"function","title":"Complex.to_string/1","doc":"Conveniency function that is used to implement the `String.Chars` and `Inspect` protocols.","ref":"Complex.html#to_string/1"},{"type":"module","title":"Complex.Kernel","doc":"Provides operator overloading for Elixir operators.\n\nWhen you `use Complex.Kernel`, be aware that the arithmetic operators\nwon't work in clause guards. For that you need to use the fully qualified\nfunctions (i.e.: `when Kernel.+(a, b) == 1`) instead.","ref":"Complex.Kernel.html"},{"type":"function","title":"Complex.Kernel.**/2","doc":"","ref":"Complex.Kernel.html#**/2"},{"type":"function","title":"Complex.Kernel.*/2","doc":"","ref":"Complex.Kernel.html#*/2"},{"type":"function","title":"Complex.Kernel.+/2","doc":"","ref":"Complex.Kernel.html#+/2"},{"type":"function","title":"Complex.Kernel.-/2","doc":"","ref":"Complex.Kernel.html#-/2"},{"type":"function","title":"Complex.Kernel.//2","doc":"","ref":"Complex.Kernel.html#//2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}